==> james-project-3.7.3-source-release.zip: james-project/server/data/data-cassandra/src/main/java/org/apache/james/user/cassandra/CassandraUsersRepositoryModule.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.user.cassandra;

import static com.datastax.driver.core.DataType.text;

import org.apache.james.backends.cassandra.components.CassandraModule;
import org.apache.james.user.cassandra.tables.CassandraUserTable;

public interface CassandraUsersRepositoryModule {
    CassandraModule MODULE = CassandraModule.table(CassandraUserTable.TABLE_NAME)
        .comment("Holds users of this James server.")
        .statement(statement -> statement
            .addPartitionKey(CassandraUserTable.NAME, text())
            .addColumn(CassandraUserTable.REALNAME, text())
            .addColumn(CassandraUserTable.PASSWORD, text())
            .addColumn(CassandraUserTable.ALGORITHM, text()))
        .build();
}

==> james-project-3.8.0-source-release.zip: james-project/server/data/data-cassandra/src/main/java/org/apache/james/user/cassandra/CassandraUsersRepositoryModule.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.user.cassandra;

import org.apache.james.backends.cassandra.components.CassandraModule;
import org.apache.james.user.cassandra.tables.CassandraUserTable;

import com.datastax.oss.driver.api.core.type.DataTypes;

public interface CassandraUsersRepositoryModule {
    CassandraModule MODULE = CassandraModule.table(CassandraUserTable.TABLE_NAME)
        .comment("Holds users of this James server.")
        .statement(statement -> types -> statement
            .withPartitionKey(CassandraUserTable.NAME, DataTypes.TEXT)
            .withColumn(CassandraUserTable.REALNAME, DataTypes.TEXT)
            .withColumn(CassandraUserTable.PASSWORD, DataTypes.TEXT)
            .withColumn(CassandraUserTable.ALGORITHM, DataTypes.TEXT)
            .withColumn(CassandraUserTable.AUTHORIZED_USERS, DataTypes.setOf(DataTypes.TEXT))
            .withColumn(CassandraUserTable.DELEGATED_USERS, DataTypes.setOf(DataTypes.TEXT)))
        .build();
}
